@@ -624,19 +624,21 @@ class XMPPClient:
                 if version != member._assignment_version:
                     member._assignment_version = version
 
-                    new_positions = {
-                        member.id: req['targetAbsoluteIdx'],
-                        req['swapTargetMemberId']: req['startingAbsoluteIdx']
-                    }
-                    if party.me.leader:
-                        await party.refresh_squad_assignments(
-                            new_positions=new_positions
-                        )
+                    swap_member_id = req['swapTargetMemberId']
+                    if swap_member_id != 'INVALID':
+                        new_positions = {
+                            member.id: req['targetAbsoluteIdx'],
+                            swap_member_id: req['startingAbsoluteIdx']
+                        }
+                        if party.me.leader:
+                            await party.refresh_squad_assignments(
+                                new_positions=new_positions
+                            )
 
-                    self.client.dispatch_event(
-                        'party_member_team_swap',
-                        *[party.members[k] for k in new_positions]
-                    )
+                        self.client.dispatch_event(
+                            'party_member_team_swap',
+                            *[party.members[k] for k in new_positions]
+                        )
 
         self.client.dispatch_event('party_member_update', member)
 
@@ -760,11 +762,12 @@ class XMPPClient:
             except (KeyError, AttributeError):
                 pass
 
-        if presence.type_ == (aioxmpp.PresenceType.UNAVAILABLE
-                              and friend.is_online()):
+        if not is_available and friend.is_online():
             friend._update_last_logout(datetime.datetime.utcnow())
+            self.client._presences.remove(user_id, None)
+        else:
+            self.client._presences.set(user_id, _pres)
 
-        self.client._presences.set(user_id, _pres)
         self.client.dispatch_event('friend_presence', _pres)
 
     def setup_callbacks(self,
